var map, markers, vectorLayer;
var markerList = new Array();
var pointsFeature;

var size = new OpenLayers.Size(10,17);
var offset = new OpenLayers.Pixel(-(size.w/2), -size.h);
var icon = new OpenLayers.Icon('./img/marker.png',size,offset);
var proj4326 = new OpenLayers.Projection("EPSG:4326");
var projmerc = new OpenLayers.Projection("EPSG:900913"); 

function init(){
	var lonlat = new OpenLayers.LonLat(13.38, 52.52);
	var zoom = 13; 

	map = new OpenLayers.Map('map', {
									controls:[
										 new OpenLayers.Control.ZoomBox(), 
										 new OpenLayers.Control.Navigation(),
										 new OpenLayers.Control.PanZoomBar(),
										 new OpenLayers.Control.KeyboardDefaults(),
										 new OpenLayers.Control.LayerSwitcher()
									],
									maxExtent:
									new OpenLayers.Bounds( -20037508.34,-20037508.34,
															20037508.34, 20037508.34),
									numZoomLevels: 18,
									maxResolution: 156543,
									units: 'm',
									projection: projmerc,
									displayProjection: proj4326 
								}
							);
	
	var osmlayer = new OpenLayers.Layer.OSM.Mapnik("Mapnik");
	map.addLayer(osmlayer); 
	
	markers = new OpenLayers.Layer.Markers( "Markers" );
    map.addLayer(markers);
	
	vectorLayer = new OpenLayers.Layer.Vector("Simple Geometry");
	map.addLayer(vectorLayer);
	
	map.setCenter(lonlat.transform(proj4326, map.getProjectionObject()), zoom);
}

function showTrip100(data) {
	for(var z = 0; z < 100; z++) {
		showTrip(data);
	}
}

function showTrip(data) {
	
	removeTrip();
	
	for(var i = 0; i < data.length; i++) {
		createMarker(data[i]);
	}
	
	map.zoomToExtent(markers.getDataExtent());
}

function removeTrip() {
	
	for(var x=0; x<markerList.length; x++) {
		markers.removeMarker(markerList[x]);
		markerList[x].destroy();
	}
	markerList.splice(0, markerList.length);
	map.removeLayer(markers);
	markers.destroy();
	
	markers = new OpenLayers.Layer.Markers( "Markers" );
	map.addLayer(markers);
}

function createMarker(dataPoint) {
	var point = new OpenLayers.LonLat(dataPoint[0],dataPoint[1]);
	var marker = new OpenLayers.Marker(point.transform(proj4326, map.getProjectionObject()), icon.clone());
	marker.timestamp = dataPoint[2];
	// marker.events.register('mouseover', marker, 
		// function(evt) { 
			// alert(this.timestamp); 
			// OpenLayers.Event.stop(evt); 
		// }
	// );
	markerList.push(marker);
	markers.addMarker(marker);
}

var timer;
function showTripWithPauseStart(data) {
	showTrip(data);
	timer = setTimeout("showTripWithPauseStart(data)",5000);
}

function showTripWithPauseStop() {
	clearTimeout(timer);
}

var points;
var p = new Array();

function showTripAsGeometry(data) {
	
	removeTripAsGeometry();
	
	var style = {
				externalGraphic: "./img/marker.png",
				graphicWidth: 10,
				graphicHeight: 7,
				graphicXOffset: -5,
				graphicYOffset: -7
            };
	
	for(var i = 0; i < data.length; i++) {
		var dataPoint = data[i];
		var point = new OpenLayers.Geometry.Point(dataPoint[0],dataPoint[1]);
		point.transform(proj4326, map.getProjectionObject());
		p.push(point);
	}
	points = new OpenLayers.Geometry.MultiPoint(p);
	pointsFeature = new OpenLayers.Feature.Vector(points,null,style);
	vectorLayer.addFeatures([pointsFeature]);
	map.zoomToExtent(vectorLayer.getDataExtent());
}

function removeTripAsGeometry() {
	
	if(p.length == 0) {
		return;
	}
	
	vectorLayer.removeFeatures([pointsFeature]);
	
	for(var x=0; x<p.length; x++) {
		points.removePoint(p[x]);
		p[x].destroy();
	}
	
	p.splice(0, p.length);
	
}

var timer2;
function showTripAsGeometryWithPauseStart(data) {
	showTripAsGeometry(data);
	timer2 = setTimeout("showTripAsGeometryWithPauseStart(data)",5000);
}

function showTripAsGeometryWithPauseStop() {
	clearTimeout(timer2);
}

function test()
{
	
}

/**
* not the best sleep in the world since it eats up CPU
*/
function sleep(s){
	s = s*1000;
	var stop = false;
	var start = new Date();
	var msStart = start.getTime();
	while(!stop){
		var now = new Date();
		var msNow = now.getTime();
		if(msNow-msStart > s) {
			stop = true;
		}
	}
}
